==> haskell-http-client-tls-0.3.5.1-17-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.5.1
id: http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J
key: http-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Client.TLS
abi: bfd2559218a81acc5cfe715436ea1e49
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/http-client-tls-0.3.5.1
hs-libraries: HShttp-client-tls-0.3.5.1-GGLWCSSIEXSCH48WwAhd8J
depends:
    base-4.10.0.0 data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    connection-0.2.8-DV3SXnPmo3U13Xbkb1AWD4
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    tls-1.4.0-DUjRpAMZEHBIySIXtFteXe bytestring-0.10.8.2
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    transformers-0.5.2.0 http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi
    memory-0.14.8-HEYe2msABjoBOvbV0yaOyF
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 containers-0.5.10.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=55d8edbe337279f21d58496f3f779cb9
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             connection-0.2.8-DV3SXnPmo3U13Xbkb1AWD4=00d5e04b887a765cbea71554bd2d160c
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             tls-1.4.0-DUjRpAMZEHBIySIXtFteXe=3640de764ce719572b5f1552b01ce71e
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             cryptonite-0.24-JQ3NPvIvMVWG9FHR2Q0Evi=1928ece35e67ec41b499da4f70bba50f
             memory-0.14.8-HEYe2msABjoBOvbV0yaOyF=4c821a304108f2b075d812c81435d53c
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-tls-0.3.5.1-18-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-client-tls.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client-tls
version: 0.3.5.1
id: http-client-tls-0.3.5.1-LB4pkcb8qGEBWLeuaQ6vBK
key: http-client-tls-0.3.5.1-LB4pkcb8qGEBWLeuaQ6vBK
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/http-client
synopsis: http-client backend using the connection package and tls library
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <https://www.stackage.org/package/http-client-tls>.
category: Network
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.HTTP.Client.TLS
abi: 2c976076a1c68f1c8d224058bac08c04
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/http-client-tls-0.3.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/http-client-tls-0.3.5.1
hs-libraries: HShttp-client-tls-0.3.5.1-LB4pkcb8qGEBWLeuaQ6vBK
depends:
    base-4.10.0.0 data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp
    http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5
    connection-0.2.8-DMHF7pH68f1CIg10bEvXf6
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
    tls-1.4.0-31ZRwpEukM6Jnw4JDFykbI bytestring-0.10.8.2
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    transformers-0.5.2.0 http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP
    memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6 containers-0.5.10.2
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             data-default-class-0.1.2.0-K0O6u0ifzTuLE4f7kBhgzp=55d8edbe337279f21d58496f3f779cb9
             http-client-0.5.7.0-34w8r0jpuHCHrZw43z9eV5=8c61cedc25822b4f93e8e07c4c9eca43
             connection-0.2.8-DMHF7pH68f1CIg10bEvXf6=ad775625a6ea9be6af13869208f6e3c5
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
             tls-1.4.0-31ZRwpEukM6Jnw4JDFykbI=9bc89678995e74c71ba5c4956aa98062
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP=302f7d9b300167b44be1bfa67778ed25
             memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ=66cafb37fc02a74908fd731801b55463
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=e190029673d5410544b32623a0e81f5f
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
haddock-interfaces: /usr/share/doc/haskell-http-client-tls/html/http-client-tls.haddock
haddock-html: /usr/share/doc/haskell-http-client-tls/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
